@@ -1,5 +1,5 @@
 if (requireNamespace("testthat", quietly = TRUE)) {
-  library(testthat)
-  library(paradox)
+  library("testthat")
+  library("paradox")
   test_check("paradox")
 }
